@@ -10,3 +10,5 @@ from .tiny_imagenet import *
 from .omniglot import *
 from .torchvision_wrapper import *
 from .inaturalist import *
+from .penn_fudan import *
+from .clear import *
