@@ -21,8 +21,10 @@ from avalanche.benchmarks.scenarios.classification_scenario import (
 from avalanche.benchmarks.scenarios.new_instances.ni_utils import (
     _exp_structure_from_assignment,
 )
-from avalanche.benchmarks.utils import AvalancheSubset, AvalancheDataset
-from avalanche.benchmarks.utils.dataset_utils import ConstantSequence
+from avalanche.benchmarks.utils import classification_subset
+from avalanche.benchmarks.utils.classification_dataset import \
+    ClassificationDataset
+from avalanche.benchmarks.utils.flat_data import ConstantSequence
 
 
 class NIScenario(GenericCLScenario["NIExperience"]):
@@ -44,8 +46,8 @@ class NIScenario(GenericCLScenario["NIExperience"]):
 
     def __init__(
         self,
-        train_dataset: AvalancheDataset,
-        test_dataset: AvalancheDataset,
+        train_dataset: ClassificationDataset,
+        test_dataset: ClassificationDataset,
         n_experiences: int,
         task_labels: bool = False,
         shuffle: bool = True,
@@ -155,7 +157,9 @@ class NIScenario(GenericCLScenario["NIExperience"]):
             included_patterns = list()
             for exp_def in fixed_exp_assignment:
                 included_patterns.extend(exp_def)
-            subset = AvalancheSubset(train_dataset, indices=included_patterns)
+            subset = classification_subset(
+                train_dataset, indices=included_patterns
+            )
             unique_targets, unique_count = torch.unique(
                 torch.as_tensor(subset.targets), return_counts=True
             )
@@ -419,7 +423,7 @@ class NIScenario(GenericCLScenario["NIExperience"]):
                 train_task_labels[-1], len(train_dataset)
             )
             train_experiences.append(
-                AvalancheSubset(
+                classification_subset(
                     train_dataset, indices=exp_def, task_labels=task_labels
                 )
             )
