@@ -1,6 +1,8 @@
 from .mean import *
 from .accuracy import *
+from .amca import *
 from .checkpoint import *
+from .class_accuracy import *
 from .confusion_matrix import *
 from .cpu_usage import *
 from .disk_usage import *
@@ -14,3 +16,4 @@ from .timing import *
 from .mean_scores import *
 from .labels_repartition import *
 from .images_samples import *
+from .topk_acc import *
