@@ -13,7 +13,7 @@ from typing import Dict, TYPE_CHECKING, Union
 
 from avalanche.evaluation.metric_definitions import Metric, PluginMetric
 from avalanche.evaluation.metric_results import MetricValue, MetricResult
-from avalanche.evaluation.metrics import Accuracy, Mean
+from avalanche.evaluation.metrics import TaskAwareAccuracy, Mean
 from avalanche.evaluation.metric_utils import (
     get_metric_name,
     phase_and_task,
@@ -21,7 +21,7 @@ from avalanche.evaluation.metric_utils import (
 )
 
 if TYPE_CHECKING:
-    from avalanche.training.templates.supervised import SupervisedTemplate
+    from avalanche.training.templates import SupervisedTemplate
 
 
 class ForwardTransfer(Metric[Union[float, None, Dict[int, float]]]):
@@ -231,7 +231,7 @@ class ExperienceForwardTransfer(GenericExperienceForwardTransfer):
     def __init__(self):
         super().__init__()
 
-        self._current_metric = Accuracy()
+        self._current_metric = TaskAwareAccuracy()
         """
         The average accuracy over the current evaluation experience
         """
@@ -370,7 +370,7 @@ class StreamForwardTransfer(GenericStreamForwardTransfer):
 
     def __init__(self):
         super().__init__()
-        self._current_metric = Accuracy()
+        self._current_metric = TaskAwareAccuracy()
         """
         The average accuracy over the current evaluation experience
         """
