@@ -19,7 +19,7 @@ from avalanche.benchmarks.scenarios import OnlineCLExperience
 from tqdm import tqdm
 
 if TYPE_CHECKING:
-    from avalanche.training.templates.supervised import SupervisedTemplate
+    from avalanche.training.templates import SupervisedTemplate
 
 
 class InteractiveLogger(TextLogger, SupervisedPlugin):
@@ -53,7 +53,6 @@ class InteractiveLogger(TextLogger, SupervisedPlugin):
     def __init__(self):
         super().__init__(file=sys.stdout)
         self._pbar = None
-        self.last_length = 0
 
     def before_training_epoch(
         self,
@@ -61,6 +60,8 @@ class InteractiveLogger(TextLogger, SupervisedPlugin):
         metric_values: List["MetricValue"],
         **kwargs
     ):
+        if isinstance(strategy.experience, OnlineCLExperience):
+            return
         super().before_training_epoch(strategy, metric_values, **kwargs)
         self._progress.total = len(strategy.dataloader)
 
@@ -70,6 +71,8 @@ class InteractiveLogger(TextLogger, SupervisedPlugin):
         metric_values: List["MetricValue"],
         **kwargs
     ):
+        if isinstance(strategy.experience, OnlineCLExperience):
+            return
         self._end_progress()
         super().after_training_epoch(strategy, metric_values, **kwargs)
 
@@ -83,12 +86,8 @@ class InteractiveLogger(TextLogger, SupervisedPlugin):
             experience = strategy.experience.logging()
             if experience.is_first_subexp:
                 super().before_training_exp(strategy, metric_values, **kwargs)
-                self._progress.total = \
-                    experience.sub_stream_length * \
-                    strategy.train_passes * \
-                    (experience.subexp_size // strategy.train_mb_size)
-                self.last_length = self._progress.total
-    
+                self._progress.total = experience.sub_stream_length
+
     def after_training_exp(
         self,
         strategy: "SupervisedTemplate",
@@ -100,6 +99,9 @@ class InteractiveLogger(TextLogger, SupervisedPlugin):
             if experience.is_last_subexp:
                 self._end_progress()
                 super().after_training_exp(strategy, metric_values, **kwargs)
+            else:
+                self._progress.update()
+                self._progress.refresh()
 
     def before_eval_exp(
         self,
@@ -125,6 +127,9 @@ class InteractiveLogger(TextLogger, SupervisedPlugin):
         metric_values: List["MetricValue"],
         **kwargs
     ):
+        if isinstance(strategy.experience, OnlineCLExperience):
+            return
+
         self._progress.update()
         self._progress.refresh()
         super().after_training_iteration(strategy, metric_values, **kwargs)
@@ -149,3 +154,12 @@ class InteractiveLogger(TextLogger, SupervisedPlugin):
         if self._pbar is not None:
             self._pbar.close()
             self._pbar = None
+
+    def __getstate__(self):
+        out = super().__getstate__()
+        del out['_pbar']
+        return out
+
+    def __setstate__(self, state):
+        state['_pbar'] = None
+        super().__setstate__(state)
