@@ -31,7 +31,8 @@ class EarlyStoppingPlugin(SupervisedPlugin):
         metric_name: str = "Top1_Acc_Stream",
         mode: str = "max",
         peval_mode: str = "epoch",
-        margin: float = .0,
+        margin: float = 0.0,
+        verbose=False,
     ):
         """Init.
 
@@ -46,14 +47,17 @@ class EarlyStoppingPlugin(SupervisedPlugin):
         :param peval_mode: one of {'epoch', 'iteration'}. Decides whether the
             early stopping should happen after `patience`
             epochs or iterations (Default='epoch').
-        :param margin: a minimal margin of improvements required to be 
-            considered best than a previous one. It should be an float, the 
-            default value is 0. That means that any improvement is considered 
+        :param margin: a minimal margin of improvements required to be
+            considered best than a previous one. It should be an float, the
+            default value is 0. That means that any improvement is considered
             better.
+        :param verbose: If True, prints a message for each update
+            (default: False).
         """
         super().__init__()
         self.val_stream_name = val_stream_name
         self.patience = patience
+        self.verbose = verbose
 
         assert peval_mode in {"epoch", "iteration"}
         self.peval_mode = peval_mode
@@ -123,7 +127,9 @@ class EarlyStoppingPlugin(SupervisedPlugin):
             if self.operator(float(val_acc - self.best_val), self.margin):
                 self.best_step = self._get_strategy_counter(strategy)
                 self.best_val = val_acc
-        
+                if self.verbose:
+                    print("EarlyStopping: new best value:", val_acc)
+
         return self.best_val
 
     def _get_strategy_counter(self, strategy):
