@@ -13,10 +13,6 @@
 This is a simple example on how to use the AR1 strategy.
 """
 
-from __future__ import absolute_import
-from __future__ import division
-from __future__ import print_function
-
 import argparse
 import torch
 from torch.nn import CrossEntropyLoss
@@ -45,8 +41,8 @@ def main(args):
     )
     # ---------
 
-    # --- SCENARIO CREATION
-    scenario = SplitCIFAR10(
+    # --- BENCHMARK CREATION
+    benchmark = SplitCIFAR10(
         5, train_transform=train_transform, eval_transform=test_transform
     )
     # ---------
@@ -57,7 +53,7 @@ def main(args):
     # TRAINING LOOP
     print("Starting experiment...")
     results = []
-    for experience in scenario.train_stream:
+    for experience in benchmark.train_stream:
         print("Start of experience: ", experience.current_experience)
         print("Current Classes: ", experience.classes_in_this_experience)
 
@@ -65,7 +61,7 @@ def main(args):
         print("Training completed")
 
         print("Computing accuracy on the whole test set")
-        results.append(cl_strategy.eval(scenario.test_stream, num_workers=0))
+        results.append(cl_strategy.eval(benchmark.test_stream, num_workers=0))
 
 
 if __name__ == "__main__":
