@@ -13,10 +13,6 @@
 This is a simple example on how to use the Deep SLDA strategy.
 """
 
-from __future__ import absolute_import
-from __future__ import division
-from __future__ import print_function
-
 import argparse
 import torch
 import warnings
