@@ -1,3 +1,9 @@
+"""
+This example tests Learning without Forgetting (LwF) on Split MNIST.
+The performance with default arguments should give an average accuracy
+of about 73%.
+"""
+
 import torch
 import argparse
 from avalanche.benchmarks import SplitMNIST
@@ -12,13 +18,6 @@ from avalanche.logging import InteractiveLogger
 from avalanche.training.plugins import EvaluationPlugin
 
 
-"""
-This example tests Learning without Forgetting (LwF) on Split MNIST.
-The performance with default arguments should give an average accuracy
-of about 73%.
-"""
-
-
 def main(args):
     model = SimpleMLP(hidden_size=args.hs)
     optimizer = torch.optim.SGD(model.parameters(), lr=args.lr)
@@ -33,8 +32,8 @@ def main(args):
     )
     print(f"Using device: {device}")
 
-    # create split scenario
-    scenario = SplitMNIST(n_experiences=5, return_task_id=False)
+    # create split benchmark
+    benchmark = SplitMNIST(n_experiences=5, return_task_id=False)
 
     interactive_logger = InteractiveLogger()
     eval_plugin = EvaluationPlugin(
@@ -66,10 +65,10 @@ def main(args):
         evaluator=eval_plugin,
     )
 
-    # train on the selected scenario with the chosen strategy
+    # train on the selected benchmark with the chosen strategy
     print("Starting experiment...")
     results = []
-    for train_batch_info in scenario.train_stream:
+    for train_batch_info in benchmark.train_stream:
         print(
             "Start training on experience ", train_batch_info.current_experience
         )
@@ -79,7 +78,7 @@ def main(args):
             "End training on experience ", train_batch_info.current_experience
         )
         print("Computing accuracy on the test set")
-        results.append(strategy.eval(scenario.test_stream[:]))
+        results.append(strategy.eval(benchmark.test_stream[:]))
 
 
 if __name__ == "__main__":
@@ -111,7 +110,7 @@ if __name__ == "__main__":
     parser.add_argument(
         "--cuda",
         type=int,
-        default=0,
+        default=-1,
         help="Specify GPU id to use. Use CPU if -1.",
     )
     args = parser.parse_args()
