@@ -9,10 +9,7 @@ from avalanche.benchmarks import (
     GenericClassificationExperience,
     GenericCLScenario,
 )
-from avalanche.benchmarks.utils import (
-    AvalancheTensorDataset,
-    AvalancheDatasetType,
-)
+from avalanche.benchmarks.utils import make_tensor_classification_dataset
 
 
 class GenericCLScenarioTests(unittest.TestCase):
@@ -23,14 +20,18 @@ class GenericCLScenarioTests(unittest.TestCase):
         tensor_y = torch.randint(0, 70, (200,))
         tensor_t = torch.randint(0, 5, (200,))
         train_exps.append(
-            AvalancheTensorDataset(tensor_x, tensor_y, task_labels=tensor_t)
+            make_tensor_classification_dataset(
+                tensor_x, tensor_y, task_labels=tensor_t
+            )
         )
 
         tensor_x = torch.rand(200, 3, 28, 28)
         tensor_y = torch.randint(0, 100, (200,))
         tensor_t = torch.randint(0, 5, (200,))
         train_exps.append(
-            AvalancheTensorDataset(tensor_x, tensor_y, task_labels=tensor_t)
+            make_tensor_classification_dataset(
+                tensor_x, tensor_y, task_labels=tensor_t
+            )
         )
 
         test_exps = []
@@ -38,7 +39,9 @@ class GenericCLScenarioTests(unittest.TestCase):
         test_y = torch.randint(100, 200, (200,))
         test_t = torch.randint(0, 5, (200,))
         test_exps.append(
-            AvalancheTensorDataset(test_x, test_y, task_labels=test_t)
+            make_tensor_classification_dataset(
+                test_x, test_y, task_labels=test_t
+            )
         )
 
         other_stream_exps = []
@@ -46,7 +49,9 @@ class GenericCLScenarioTests(unittest.TestCase):
         other_y = torch.randint(400, 600, (200,))
         other_t = torch.randint(0, 5, (200,))
         other_stream_exps.append(
-            AvalancheTensorDataset(other_x, other_y, task_labels=other_t)
+            make_tensor_classification_dataset(
+                other_x, other_y, task_labels=other_t
+            )
         )
 
         benchmark_instance = dataset_benchmark(
@@ -98,14 +103,18 @@ class GenericCLScenarioTests(unittest.TestCase):
         tensor_y = torch.randint(0, 70, (200,))
         tensor_t = torch.randint(0, 5, (200,))
         train_exps.append(
-            AvalancheTensorDataset(tensor_x, tensor_y, task_labels=tensor_t)
+            make_tensor_classification_dataset(
+                tensor_x, tensor_y, task_labels=tensor_t
+            )
         )
 
         tensor_x = torch.rand(200, 3, 28, 28)
         tensor_y = torch.randint(0, 100, (200,))
         tensor_t = torch.randint(0, 5, (200,))
         train_exps.append(
-            AvalancheTensorDataset(tensor_x, tensor_y, task_labels=tensor_t)
+            make_tensor_classification_dataset(
+                tensor_x, tensor_y, task_labels=tensor_t
+            )
         )
 
         test_exps = []
@@ -113,7 +122,9 @@ class GenericCLScenarioTests(unittest.TestCase):
         test_y = torch.randint(100, 200, (200,))
         test_t = torch.randint(0, 5, (200,))
         test_exps.append(
-            AvalancheTensorDataset(test_x, test_y, task_labels=test_t)
+            make_tensor_classification_dataset(
+                test_x, test_y, task_labels=test_t
+            )
         )
 
         other_stream_exps = []
@@ -121,7 +132,9 @@ class GenericCLScenarioTests(unittest.TestCase):
         other_y = torch.randint(400, 600, (200,))
         other_t = torch.randint(0, 5, (200,))
         other_stream_exps.append(
-            AvalancheTensorDataset(other_x, other_y, task_labels=other_t)
+            make_tensor_classification_dataset(
+                other_x, other_y, task_labels=other_t
+            )
         )
 
         benchmark_instance = dataset_benchmark(
@@ -512,11 +525,8 @@ class GenericCLScenarioTests(unittest.TestCase):
         tensor_y = torch.randint(0, 70, (200,))
         tensor_t = torch.randint(0, 5, (200,))
         train_exps.append(
-            AvalancheTensorDataset(
-                tensor_x,
-                tensor_y,
-                task_labels=tensor_t,
-                dataset_type=AvalancheDatasetType.CLASSIFICATION,
+            make_tensor_classification_dataset(
+                tensor_x, tensor_y, task_labels=tensor_t
             )
         )
 
@@ -524,11 +534,8 @@ class GenericCLScenarioTests(unittest.TestCase):
         tensor_y = torch.randint(0, 100, (200,))
         tensor_t = torch.randint(0, 5, (200,))
         train_exps.append(
-            AvalancheTensorDataset(
-                tensor_x,
-                tensor_y,
-                task_labels=tensor_t,
-                dataset_type=AvalancheDatasetType.CLASSIFICATION,
+            make_tensor_classification_dataset(
+                tensor_x, tensor_y, task_labels=tensor_t
             )
         )
 
@@ -537,11 +544,8 @@ class GenericCLScenarioTests(unittest.TestCase):
         test_y = torch.randint(100, 200, (200,))
         test_t = torch.randint(0, 5, (200,))
         test_exps.append(
-            AvalancheTensorDataset(
-                test_x,
-                test_y,
-                task_labels=test_t,
-                dataset_type=AvalancheDatasetType.CLASSIFICATION,
+            make_tensor_classification_dataset(
+                test_x, test_y, task_labels=test_t
             )
         )
 
@@ -550,11 +554,8 @@ class GenericCLScenarioTests(unittest.TestCase):
         other_y = torch.randint(400, 600, (200,))
         other_t = torch.randint(0, 5, (200,))
         other_stream_exps.append(
-            AvalancheTensorDataset(
-                other_x,
-                other_y,
-                task_labels=other_t,
-                dataset_type=AvalancheDatasetType.CLASSIFICATION,
+            make_tensor_classification_dataset(
+                other_x, other_y, task_labels=other_t
             )
         )
 
