@@ -1,8 +1,11 @@
 import unittest
 
 import torch
-from avalanche.benchmarks.utils import AvalancheTensorDataset
+from torch.utils.data import TensorDataset
+
+from avalanche.benchmarks.utils import make_tensor_classification_dataset
 from avalanche.benchmarks import GenericCLScenario
+from avalanche.benchmarks.utils import make_classification_dataset
 
 
 class CustomStreamsTests(unittest.TestCase):
@@ -17,7 +20,11 @@ class CustomStreamsTests(unittest.TestCase):
             tensor_y = torch.randint(0, 100, (200,))
             tensor_t = torch.randint(0, 5, (200,))
             train_exps.append(
-                AvalancheTensorDataset(tensor_x, tensor_y, task_labels=tensor_t)
+                make_classification_dataset(
+                    TensorDataset(tensor_x, tensor_y),
+                    targets=tensor_y,
+                    task_labels=tensor_t,
+                )
             )
 
         for _ in range(3):
@@ -25,7 +32,11 @@ class CustomStreamsTests(unittest.TestCase):
             tensor_y = torch.randint(0, 100, (150,))
             tensor_t = torch.randint(0, 3, (150,))
             test_exps.append(
-                AvalancheTensorDataset(tensor_x, tensor_y, task_labels=tensor_t)
+                make_classification_dataset(
+                    TensorDataset(tensor_x, tensor_y),
+                    targets=tensor_y,
+                    task_labels=tensor_t,
+                )
             )
 
         for _ in range(4):
@@ -33,11 +44,16 @@ class CustomStreamsTests(unittest.TestCase):
             tensor_y = torch.randint(0, 100, (220,))
             tensor_t = torch.randint(0, 5, (220,))
             valid_exps.append(
-                AvalancheTensorDataset(tensor_x, tensor_y, task_labels=tensor_t)
+                make_classification_dataset(
+                    TensorDataset(tensor_x, tensor_y),
+                    targets=tensor_y,
+                    task_labels=tensor_t,
+                )
             )
 
-        valid_origin_dataset = AvalancheTensorDataset(
-            torch.ones(10, 3, 32, 32), torch.zeros(10)
+        valid_origin_dataset = make_classification_dataset(
+            TensorDataset(torch.ones(10, 3, 32, 32), torch.zeros(10)),
+            targets=torch.zeros(10),
         )
 
         valid_t_labels = [{9}, {4, 5}, {7, 8}, {0}, {3}]
@@ -116,7 +132,9 @@ class CustomStreamsTests(unittest.TestCase):
             tensor_y = torch.randint(0, 100, (200,))
             tensor_t = torch.randint(0, 5, (200,))
             train_exps.append(
-                AvalancheTensorDataset(tensor_x, tensor_y, task_labels=tensor_t)
+                make_tensor_classification_dataset(
+                    tensor_x, tensor_y, task_labels=tensor_t
+                )
             )
 
         for _ in range(3):
@@ -124,7 +142,9 @@ class CustomStreamsTests(unittest.TestCase):
             tensor_y = torch.randint(0, 100, (150,))
             tensor_t = torch.randint(0, 5, (150,))
             test_exps.append(
-                AvalancheTensorDataset(tensor_x, tensor_y, task_labels=tensor_t)
+                make_tensor_classification_dataset(
+                    tensor_x, tensor_y, task_labels=tensor_t
+                )
             )
 
         with self.assertRaises(Exception):
