@@ -1,7 +1,13 @@
 import unittest
 
+import avalanche.benchmarks.datasets.external_datasets.fmnist
 from avalanche.benchmarks import ClassificationExperience, SplitFMNIST
-from tests.unit_tests_utils import load_experience_train_eval
+
+from tests.unit_tests_utils import (
+    load_experience_train_eval,
+    FAST_TEST,
+    is_github_action,
+)
 
 MNIST_DOWNLOADS = 0
 MNIST_DOWNLOAD_METHOD = None
@@ -10,25 +16,33 @@ MNIST_DOWNLOAD_METHOD = None
 class FMNISTBenchmarksTests(unittest.TestCase):
     def setUp(self):
         import avalanche.benchmarks.classic.cfashion_mnist as cfashion_mnist
+        from avalanche.benchmarks.datasets.external_datasets.fmnist import \
+            get_fmnist_dataset
 
         global MNIST_DOWNLOAD_METHOD
-        MNIST_DOWNLOAD_METHOD = cfashion_mnist._get_fmnist_dataset
+        MNIST_DOWNLOAD_METHOD = get_fmnist_dataset
 
         def count_downloads(*args, **kwargs):
             global MNIST_DOWNLOADS
             MNIST_DOWNLOADS += 1
             return MNIST_DOWNLOAD_METHOD(*args, **kwargs)
 
-        cfashion_mnist._get_fmnist_dataset = count_downloads
+        avalanche.benchmarks.datasets.external_datasets.fmnist.\
+            get_fmnist_dataset = count_downloads
 
     def tearDown(self):
         global MNIST_DOWNLOAD_METHOD
         if MNIST_DOWNLOAD_METHOD is not None:
             import avalanche.benchmarks.classic.cfashion_mnist as cfashion_mnist
 
-            cfashion_mnist._get_fmnist_dataset = MNIST_DOWNLOAD_METHOD
+            avalanche.benchmarks.datasets.external_datasets.fmnist.\
+                get_fmnist_dataset = MNIST_DOWNLOAD_METHOD
             MNIST_DOWNLOAD_METHOD = None
 
+    @unittest.skipIf(
+        FAST_TEST or is_github_action(),
+        "We don't want to download large datasets in github actions.",
+    )
     def test_SplitFMNIST_benchmark(self):
         benchmark = SplitFMNIST(5)
         self.assertEqual(5, len(benchmark.train_stream))
