@@ -5,11 +5,11 @@ import unittest
 import torch
 
 from avalanche.evaluation.metrics import (
-    Accuracy,
+    TaskAwareAccuracy,
     AverageMeanClassAccuracy,
     MultiStreamAMCA,
     ClassAccuracy,
-    Loss,
+    TaskAwareLoss,
     ConfusionMatrix,
     DiskUsage,
     MAC,
@@ -42,7 +42,7 @@ class GeneralMetricTests(unittest.TestCase):
         self.task_labels = torch.randint(0, self.n_tasks, (self.batch_size,))
 
     def test_accuracy(self):
-        metric = Accuracy()
+        metric = TaskAwareAccuracy()
         self.assertEqual(metric.result(), {})
         metric.update(self.out, self.y, 0)
         self.assertLessEqual(metric.result(0)[0], 1)
@@ -51,7 +51,7 @@ class GeneralMetricTests(unittest.TestCase):
         self.assertEqual(metric.result(), {})
 
     def test_accuracy_task_per_pattern(self):
-        metric = Accuracy()
+        metric = TaskAwareAccuracy()
         self.assertEqual(metric.result(), {})
         metric.update(self.out, self.y, self.task_labels)
         out = metric.result()
@@ -83,9 +83,9 @@ class GeneralMetricTests(unittest.TestCase):
                 self.assertGreaterEqual(class_accuracy, 0)
 
         metric.reset()
-        self.assertDictEqual(metric.result(), {0: {
-            int(c): 0.0 for c in torch.unique(self.y)
-        }})
+        self.assertDictEqual(
+            metric.result(), {0: {int(c): 0.0 for c in torch.unique(self.y)}}
+        )
 
     def test_class_accuracy_extended(self):
         metric = ClassAccuracy()
@@ -95,154 +95,71 @@ class GeneralMetricTests(unittest.TestCase):
         # 0: 50%, 1: 100%, 2: 0%
         metric.update(my_out, my_y, 0)
 
-        self.assertDictEqual(metric.result(), {
-            0: {
-                0: 0.5,
-                1: 1.00,
-                2: 0.0
-            }
-        })
+        self.assertDictEqual(metric.result(), {0: {0: 0.5, 1: 1.00, 2: 0.0}})
 
         metric.reset()
-        self.assertDictEqual(metric.result(), {
-            0: {
-                0: 0.0,
-                1: 0.0,
-                2: 0.0
-            }
-        })
+        self.assertDictEqual(metric.result(), {0: {0: 0.0, 1: 0.0, 2: 0.0}})
 
         # Add a task
         metric.update(my_out, my_y, 1)
-        self.assertDictEqual(metric.result(), {
-            0: {
-                0: 0.0,
-                1: 0.0,
-                2: 0.0
-            },
-            1: {
-                0: 0.5,
-                1: 1.00,
-                2: 0.0
-            }
-        })
+        self.assertDictEqual(
+            metric.result(),
+            {0: {0: 0.0, 1: 0.0, 2: 0.0}, 1: {0: 0.5, 1: 1.00, 2: 0.0}},
+        )
 
         metric.reset()
-        self.assertDictEqual(metric.result(), {
-            0: {
-                0: 0.0,
-                1: 0.0,
-                2: 0.0
-            },
-            1: {
-                0: 0.0,
-                1: 0.0,
-                2: 0.0
-            }
-        })
+        self.assertDictEqual(
+            metric.result(),
+            {0: {0: 0.0, 1: 0.0, 2: 0.0}, 1: {0: 0.0, 1: 0.0, 2: 0.0}},
+        )
 
     def test_class_accuracy_static(self):
         with self.assertRaises(Exception):
-            metric = ClassAccuracy(
-                classes={
-                    0: (0, 1, 2, 'aaa'),
-                    1: (0, 1, 2)
-                }
-            )
+            metric = ClassAccuracy(classes={0: (0, 1, 2, "aaa"), 1: (0, 1, 2)})
 
-        metric = ClassAccuracy(
-            classes={
-                0: (0, 1, 2),
-                1: (0, 1, 2)
-            }
+        metric = ClassAccuracy(classes={0: (0, 1, 2), 1: (0, 1, 2)})
+        self.assertDictEqual(
+            metric.result(),
+            {0: {0: 0.0, 1: 0.0, 2: 0.0}, 1: {0: 0.0, 1: 0.0, 2: 0.0}},
         )
-        self.assertDictEqual(metric.result(), {
-            0: {
-                0: 0.0,
-                1: 0.0,
-                2: 0.0
-            },
-            1: {
-                0: 0.0,
-                1: 0.0,
-                2: 0.0
-            }
-        })
 
         metric.reset()
-        self.assertDictEqual(metric.result(), {
-            0: {
-                0: 0.0,
-                1: 0.0,
-                2: 0.0
-            },
-            1: {
-                0: 0.0,
-                1: 0.0,
-                2: 0.0
-            }
-        })
+        self.assertDictEqual(
+            metric.result(),
+            {0: {0: 0.0, 1: 0.0, 2: 0.0}, 1: {0: 0.0, 1: 0.0, 2: 0.0}},
+        )
 
         my_y = torch.as_tensor([0, 0, 1, 0, 2, 2, 0])
         my_out = torch.as_tensor([0, 0, 1, 2, 1, 1, 1])
         # 0: 50%, 1: 100%, 2: 0%
         metric.update(my_out, my_y, 0)
 
-        self.assertDictEqual(metric.result(), {
-            0: {
-                0: 0.5,
-                1: 1.00,
-                2: 0.0
-            },
-            1: {
-                0: 0.0,
-                1: 0.0,
-                2: 0.0
-            }
-        })
+        self.assertDictEqual(
+            metric.result(),
+            {0: {0: 0.5, 1: 1.00, 2: 0.0}, 1: {0: 0.0, 1: 0.0, 2: 0.0}},
+        )
 
         metric.reset()
-        self.assertDictEqual(metric.result(), {
-            0: {
-                0: 0.0,
-                1: 0.0,
-                2: 0.0
-            },
-            1: {
-                0: 0.0,
-                1: 0.0,
-                2: 0.0
-            }
-        })
+        self.assertDictEqual(
+            metric.result(),
+            {0: {0: 0.0, 1: 0.0, 2: 0.0}, 1: {0: 0.0, 1: 0.0, 2: 0.0}},
+        )
 
         # Add a task
         metric.update(my_out, my_y, 1)
-        self.assertDictEqual(metric.result(), {
-            0: {
-                0: 0.0,
-                1: 0.0,
-                2: 0.0
-            },
-            1: {
-                0: 0.5,
-                1: 1.00,
-                2: 0.0
-            }
-        })
+        self.assertDictEqual(
+            metric.result(),
+            {0: {0: 0.0, 1: 0.0, 2: 0.0}, 1: {0: 0.5, 1: 1.00, 2: 0.0}},
+        )
 
         metric.reset()
-        self.assertDictEqual(metric.result(), {
-            0: {
-                0: 0.0,
-                1: 0.0,
-                2: 0.0
+        self.assertDictEqual(
+            metric.result(),
+            {
+                0: {0: 0.0, 1: 0.0, 2: 0.0},
+                1: {0: 0.0, 1: 0.0, 2: 0.0},
             },
-            1: {
-                0: 0.0,
-                1: 0.0,
-                2: 0.0
-            },
-        })
+        )
 
     def test_amca_first_update(self):
         metric = AverageMeanClassAccuracy()
@@ -264,30 +181,20 @@ class GeneralMetricTests(unittest.TestCase):
         self.assertDictEqual(metric.result(), {})
 
         metric.update(my_out, my_y, 0)
-        self.assertDictEqual(metric.result(), {
-            0: my_amca
-        })
+        self.assertDictEqual(metric.result(), {0: my_amca})
 
         metric.reset()
         metric.next_experience()
         # After reset, previously dynamically added tasks are remembered
-        self.assertDictEqual(metric.result(), {
-            0: 0.0
-        })
+        self.assertDictEqual(metric.result(), {0: 0.0})
 
         metric.update(my_out, my_y, 0)
-        self.assertDictEqual(metric.result(), {
-            0: my_amca
-        })
+        self.assertDictEqual(metric.result(), {0: my_amca})
 
         metric.update(my_out2, my_y2, 0)
-        self.assertDictEqual(metric.result(), {
-            0: my_amca_1_and_2
-        })
+        self.assertDictEqual(metric.result(), {0: my_amca_1_and_2})
         metric.next_experience()
-        self.assertDictEqual(metric.result(), {
-            0: my_amca_1_and_2 / 2
-        })
+        self.assertDictEqual(metric.result(), {0: my_amca_1_and_2 / 2})
 
     def test_amca_single_task_dynamic(self):
         metric = AverageMeanClassAccuracy()
@@ -306,29 +213,19 @@ class GeneralMetricTests(unittest.TestCase):
         my_amca_1_and_2 = (my_amca + my_amca2) / 2
 
         metric.update(my_out, my_y, 0)
-        self.assertDictEqual(metric.result(), {
-            0: my_amca
-        })
+        self.assertDictEqual(metric.result(), {0: my_amca})
 
         metric.reset()
         # After reset, previously dynamically added tasks are remembered
-        self.assertDictEqual(metric.result(), {
-            0: 0.0
-        })
+        self.assertDictEqual(metric.result(), {0: 0.0})
 
         metric.update(my_out, my_y, 0)
-        self.assertDictEqual(metric.result(), {
-            0: my_amca
-        })
+        self.assertDictEqual(metric.result(), {0: my_amca})
 
         metric.update(my_out2, my_y2, 0)
-        self.assertDictEqual(metric.result(), {
-            0: my_amca_1_and_2
-        })
+        self.assertDictEqual(metric.result(), {0: my_amca_1_and_2})
         metric.next_experience()
-        self.assertDictEqual(metric.result(), {
-            0: my_amca_1_and_2 / 2
-        })
+        self.assertDictEqual(metric.result(), {0: my_amca_1_and_2 / 2})
 
     def test_amca_two_task_dynamic(self):
         metric = AverageMeanClassAccuracy()
@@ -347,69 +244,37 @@ class GeneralMetricTests(unittest.TestCase):
         my_amca_1_and_2 = (my_amca + my_amca2) / 2
 
         metric.update(my_out, my_y, 0)
-        self.assertDictEqual(metric.result(), {
-            0: my_amca
-        })
+        self.assertDictEqual(metric.result(), {0: my_amca})
 
         metric.reset()
         # After reset, previously dynamically added tasks are remembered
-        self.assertDictEqual(metric.result(), {
-            0: 0.0
-        })
+        self.assertDictEqual(metric.result(), {0: 0.0})
 
         metric.update(my_out, my_y, 0)
-        self.assertDictEqual(metric.result(), {
-            0: my_amca
-        })
+        self.assertDictEqual(metric.result(), {0: my_amca})
 
         metric.update(my_out2, my_y2, 1)
-        self.assertDictEqual(metric.result(), {
-            0: my_amca,
-            1: my_amca2
-        })
+        self.assertDictEqual(metric.result(), {0: my_amca, 1: my_amca2})
         metric.next_experience()
-        self.assertDictEqual(metric.result(), {
-            0: my_amca / 2,
-            1: my_amca2 / 2
-        })
+        self.assertDictEqual(metric.result(), {0: my_amca / 2, 1: my_amca2 / 2})
 
         metric.reset()
-        self.assertDictEqual(metric.result(), {
-            0: 0.0,
-            1: 0.0
-        })
+        self.assertDictEqual(metric.result(), {0: 0.0, 1: 0.0})
 
     def test_amca_two_task_static(self):
         # Test AMCA by passing the classes parameter (non-dynamic)
         with self.assertRaises(Exception):
             metric = AverageMeanClassAccuracy(
-                classes={
-                    0: (0, 1, 2, 'aaa'),
-                    1: (0, 1, 2)
-                }
+                classes={0: (0, 1, 2, "aaa"), 1: (0, 1, 2)}
             )
 
-        metric = AverageMeanClassAccuracy(
-            classes={
-                0: (0, 1, 2),
-                1: (0, 1, 2)
-            }
-        )
-        self.assertDictEqual(metric.result(), {
-            0: 0.0,
-            1: 0.0
-        })
+        metric = AverageMeanClassAccuracy(classes={0: (0, 1, 2), 1: (0, 1, 2)})
+        self.assertDictEqual(metric.result(), {0: 0.0, 1: 0.0})
         metric.reset()
-        self.assertDictEqual(metric.result(), {
-            0: 0.0,
-            1: 0.0
-        })
+        self.assertDictEqual(metric.result(), {0: 0.0, 1: 0.0})
 
         metric.next_experience()
-        self.assertDictEqual(metric.result(), {
-            0: 0.0,
-            1: 0.0
-        })
+        self.assertDictEqual(metric.result(), {0: 0.0, 1: 0.0})
         metric.reset()
 
         my_y = torch.as_tensor([0, 0, 1, 0, 2, 2, 0])
@@ -425,58 +290,37 @@ class GeneralMetricTests(unittest.TestCase):
         my_amca_1_and_2 = (my_amca + my_amca2) / 2
 
         metric.update(my_out, my_y, 0)
-        self.assertDictEqual(metric.result(), {
-            0: my_amca,
-            1: 0.0
-        })
+        self.assertDictEqual(metric.result(), {0: my_amca, 1: 0.0})
 
         metric.reset()
         # After reset, previously dynamically added tasks are remembered
-        self.assertDictEqual(metric.result(), {
-            0: 0.0,
-            1: 0.0
-        })
+        self.assertDictEqual(metric.result(), {0: 0.0, 1: 0.0})
 
         metric.update(my_out, my_y, 0)
-        self.assertDictEqual(metric.result(), {
-            0: my_amca,
-            1: 0.0
-        })
+        self.assertDictEqual(metric.result(), {0: my_amca, 1: 0.0})
 
         metric.update(my_out2, my_y2, 1)
-        self.assertDictEqual(metric.result(), {
-            0: my_amca,
-            1: my_amca2
-        })
+        self.assertDictEqual(metric.result(), {0: my_amca, 1: my_amca2})
         metric.next_experience()
-        self.assertDictEqual(metric.result(), {
-            0: my_amca / 2,
-            1: my_amca2 / 2
-        })
+        self.assertDictEqual(metric.result(), {0: my_amca / 2, 1: my_amca2 / 2})
 
         many_ts = [0] * len(my_out)
         many_ts += [1] * len(my_out2)
         metric.update(
             torch.cat((my_out, my_out2)),
             torch.cat((my_y, my_y2)),
-            torch.as_tensor(many_ts))
+            torch.as_tensor(many_ts),
+        )
 
-        self.assertDictEqual(metric.result(), {
-            0: my_amca,
-            1: my_amca2
-        })
+        self.assertDictEqual(metric.result(), {0: my_amca, 1: my_amca2})
 
         metric.next_experience()
-        self.assertDictEqual(metric.result(), {
-            0: my_amca * 2 / 3,
-            1: my_amca2 * 2 / 3
-        })
+        self.assertDictEqual(
+            metric.result(), {0: my_amca * 2 / 3, 1: my_amca2 * 2 / 3}
+        )
 
         metric.reset()
-        self.assertDictEqual(metric.result(), {
-            0: 0.0,
-            1: 0.0
-        })
+        self.assertDictEqual(metric.result(), {0: 0.0, 1: 0.0})
 
     def test_multistream_amca_two_task_dynamic(self):
         metric = MultiStreamAMCA()
@@ -496,85 +340,51 @@ class GeneralMetricTests(unittest.TestCase):
             # Should call next_experience first
             metric.update(my_out, my_y, 0)
 
-        metric.set_stream('test')
+        metric.set_stream("test")
         metric.update(my_out, my_y, 0)
-        self.assertDictEqual(metric.result(), {
-            'test': {
-                0: my_amca
-            }
-        })
+        self.assertDictEqual(metric.result(), {"test": {0: my_amca}})
 
         metric.reset()
         # After reset, previously dynamically added tasks are remembered
-        self.assertDictEqual(metric.result(), {
-            'test': {
-                0: 0.0
-            }
-        })
+        self.assertDictEqual(metric.result(), {"test": {0: 0.0}})
 
         with self.assertRaises(RuntimeError):
             # Again, should call next_experience first, even after reset
             metric.update(my_out, my_y, 0)
 
-        metric.set_stream('test')
+        metric.set_stream("test")
         metric.update(my_out, my_y, 0)
-        self.assertDictEqual(metric.result(), {
-            'test': {
-                0: my_amca
-            }
-        })
+        self.assertDictEqual(metric.result(), {"test": {0: my_amca}})
 
-        metric.set_stream('train')
-        self.assertDictEqual(metric.result(), {
-            'test': {
-                0: my_amca
-            },
-            'train': {}
-        })
+        metric.set_stream("train")
+        self.assertDictEqual(
+            metric.result(), {"test": {0: my_amca}, "train": {}}
+        )
 
         metric.update(my_out2, my_y2, 1)
-        self.assertDictEqual(metric.result(), {
-            'test': {
-                0: my_amca
-            },
-            'train': {
-                1: my_amca2
-            }
-        })
+        self.assertDictEqual(
+            metric.result(), {"test": {0: my_amca}, "train": {1: my_amca2}}
+        )
 
-        metric.set_stream('test')
-        self.assertDictEqual(metric.result(), {
-            'test': {
-                0: my_amca
-            },
-            'train': {
-                1: my_amca2
-            }
-        })
+        metric.set_stream("test")
+        self.assertDictEqual(
+            metric.result(), {"test": {0: my_amca}, "train": {1: my_amca2}}
+        )
 
         metric.finish_phase()
-        metric.set_stream('train')
-        self.assertDictEqual(metric.result(), {
-            'test': {
-                0: my_amca / 2
-            },
-            'train': {
-                1: my_amca2 / 2
-            }
-        })
+        metric.set_stream("train")
+        self.assertDictEqual(
+            metric.result(),
+            {"test": {0: my_amca / 2}, "train": {1: my_amca2 / 2}},
+        )
 
         metric.reset()
-        self.assertDictEqual(metric.result(), {
-            'test': {
-                0: 0.0
-            },
-            'train': {
-                1: 0.0
-            }
-        })
+        self.assertDictEqual(
+            metric.result(), {"test": {0: 0.0}, "train": {1: 0.0}}
+        )
 
     def test_loss(self):
-        metric = Loss()
+        metric = TaskAwareLoss()
         self.assertEqual(metric.result(0)[0], 0)
         metric.update(torch.tensor(1.0), self.batch_size, 0)
         self.assertGreaterEqual(metric.result(0)[0], 0)
@@ -582,7 +392,7 @@ class GeneralMetricTests(unittest.TestCase):
         self.assertEqual(metric.result(), {})
 
     def test_loss_multi_task(self):
-        metric = Loss()
+        metric = TaskAwareLoss()
         self.assertEqual(metric.result(), {})
         metric.update(torch.tensor(1.0), 1, 0)
         metric.update(torch.tensor(2.0), 1, 1)
