@@ -6,7 +6,7 @@ from torchvision.datasets import MNIST
 
 from avalanche.benchmarks.datasets import default_dataset_location
 from avalanche.benchmarks.scenarios.new_classes import NCExperience
-from avalanche.benchmarks.utils import AvalancheSubset
+from avalanche.benchmarks.utils import classification_subset
 from avalanche.benchmarks.scenarios.new_classes.nc_utils import (
     make_nc_transformation_subset,
 )
@@ -293,7 +293,9 @@ class MultiTaskTests(unittest.TestCase):
         train_part2 = make_nc_transformation_subset(
             mnist_train, None, None, range(3, 10)
         )
-        train_part2 = AvalancheSubset(train_part2, class_mapping=split_mapping)
+        train_part2 = classification_subset(
+            train_part2, class_mapping=split_mapping
+        )
 
         test_part1 = make_nc_transformation_subset(
             mnist_test, None, None, range(3)
@@ -301,7 +303,9 @@ class MultiTaskTests(unittest.TestCase):
         test_part2 = make_nc_transformation_subset(
             mnist_test, None, None, range(3, 10)
         )
-        test_part2 = AvalancheSubset(test_part2, class_mapping=split_mapping)
+        test_part2 = classification_subset(
+            test_part2, class_mapping=split_mapping
+        )
         my_nc_benchmark = nc_benchmark(
             [train_part1, train_part2],
             [test_part1, test_part2],
