@@ -351,6 +351,15 @@ class PluginTests(unittest.TestCase):
             set(bench1.streams.keys()), set(bench2.streams.keys())
         )
 
+        def get_mbatch(data, batch_size=5):
+            dl = DataLoader(
+                data,
+                shuffle=False,
+                batch_size=batch_size,
+                collate_fn=data.collate_fn,
+            )
+            return next(iter(dl))
+
         for stream_name in list(bench1.streams.keys()):
             for exp1, exp2 in zip(
                 bench1.streams[stream_name], bench2.streams[stream_name]
@@ -358,8 +367,12 @@ class PluginTests(unittest.TestCase):
                 dataset1 = exp1.dataset
                 dataset2 = exp2.dataset
                 for t_idx in range(3):
-                    dataset1_content = dataset1[:][t_idx]
-                    dataset2_content = dataset2[:][t_idx]
+                    dataset1_content = get_mbatch(dataset1, len(dataset1))[
+                        t_idx
+                    ]
+                    dataset2_content = get_mbatch(dataset2, len(dataset2))[:][
+                        t_idx
+                    ]
                     self.assertTrue(
                         torch.equal(dataset1_content, dataset2_content)
                     )
@@ -553,7 +566,8 @@ class PluginTests(unittest.TestCase):
     @unittest.skipIf(
         FAST_TEST,
         "skip test because it is extremely slow "
-        "and should not be broken easily.")
+        "and should not be broken easily.",
+    )
     def test_scheduler_reduce_on_plateau_plugin_with_val_stream(self):
         # Regression test for issue #858 (part 2)
         n_epochs = 100
