@@ -18,7 +18,7 @@ from torch.optim import SGD
 
 from avalanche.evaluation.metrics import StreamAccuracy, loss_metrics
 from avalanche.logging import TextLogger, InteractiveLogger
-from avalanche.models import SimpleMLP, IncrementalClassifier, PNN
+from avalanche.models import SimpleMLP, MTSimpleMLP, IncrementalClassifier, PNN
 from avalanche.training.plugins import (
     EvaluationPlugin,
     SupervisedPlugin,
@@ -42,17 +42,46 @@ from avalanche.training.supervised import (
     CoPE,
     StreamingLDA,
     MAS,
+    BiC,
+    MIR,
+    ER_ACE,
 )
 from avalanche.training.supervised.cumulative import Cumulative
 from avalanche.training.supervised.icarl import ICaRL
 from avalanche.training.supervised.joint_training import AlreadyTrainedError
 from avalanche.training.supervised.strategy_wrappers import PNNStrategy
-from avalanche.training.templates.supervised import SupervisedTemplate
+from avalanche.training.templates import SupervisedTemplate
+from avalanche.training.templates.base import _group_experiences_by_stream
 from avalanche.training.utils import get_last_fc_layer
 from tests.unit_tests_utils import get_fast_benchmark, get_device
 
 
 class BaseStrategyTest(unittest.TestCase):
+    def test_eval_streams_normalization(self):
+        benchmark = get_fast_benchmark()
+        train_len = len(benchmark.train_stream)
+        test_len = len(benchmark.test_stream)
+
+        res = _group_experiences_by_stream(benchmark.test_stream)
+        assert len(res) == 1
+        assert len(res[0]) == test_len
+
+        res = _group_experiences_by_stream([benchmark.test_stream])
+        assert len(res) == 1
+        assert len(res[0]) == test_len
+
+        res = _group_experiences_by_stream(
+            [*benchmark.test_stream, *benchmark.train_stream])
+        assert len(res) == 2
+        assert len(res[0]) == test_len
+        assert len(res[1]) == train_len
+
+        res = _group_experiences_by_stream(
+            [benchmark.test_stream, benchmark.train_stream])
+        assert len(res) == 2
+        assert len(res[0]) == test_len
+        assert len(res[1]) == train_len
+
     def test_periodic_eval(self):
         model = SimpleMLP(input_size=6, hidden_size=10)
         model.classifier = IncrementalClassifier(model.classifier.in_features)
@@ -223,16 +252,18 @@ class StrategyTest(unittest.TestCase):
     else:
         device = "cpu"
 
-    def init_sit(self):
-        model = self.get_model(fast_test=True)
+    def init_scenario(self, multi_task=False):
+        model = self.get_model(fast_test=True, multi_task=multi_task)
         optimizer = SGD(model.parameters(), lr=1e-3)
         criterion = CrossEntropyLoss()
-        benchmark = self.load_benchmark(use_task_labels=False)
+        benchmark = self.load_benchmark(use_task_labels=multi_task)
         return model, optimizer, criterion, benchmark
 
     def test_naive(self):
         # SIT scenario
-        model, optimizer, criterion, my_nc_benchmark = self.init_sit()
+        model, optimizer, criterion, benchmark = self.init_scenario(
+            multi_task=False
+        )
         strategy = Naive(
             model,
             optimizer,
@@ -242,9 +273,12 @@ class StrategyTest(unittest.TestCase):
             eval_mb_size=50,
             train_epochs=2,
         )
-        self.run_strategy(my_nc_benchmark, strategy)
+        self.run_strategy(benchmark, strategy)
 
         # MT scenario
+        model, optimizer, criterion, benchmark = self.init_scenario(
+            multi_task=True
+        )
         strategy = Naive(
             model,
             optimizer,
@@ -254,7 +288,6 @@ class StrategyTest(unittest.TestCase):
             eval_mb_size=50,
             train_epochs=2,
         )
-        benchmark = self.load_benchmark(use_task_labels=True)
         self.run_strategy(benchmark, strategy)
 
     def test_joint(self):
@@ -276,7 +309,9 @@ class StrategyTest(unittest.TestCase):
                 assert len(strategy.adapted_dataset) == cum_len
 
         # SIT scenario
-        model, optimizer, criterion, my_nc_benchmark = self.init_sit()
+        model, optimizer, criterion, benchmark = self.init_scenario(
+            multi_task=False
+        )
         strategy = JointTraining(
             model,
             optimizer,
@@ -285,13 +320,15 @@ class StrategyTest(unittest.TestCase):
             device=self.device,
             eval_mb_size=50,
             train_epochs=2,
-            plugins=[JointSTestPlugin(my_nc_benchmark)],
+            plugins=[JointSTestPlugin(benchmark)],
         )
         strategy.evaluator.loggers = [TextLogger(sys.stdout)]
-        strategy.train(my_nc_benchmark.train_stream)
+        strategy.train(benchmark.train_stream)
 
         # MT scenario
-        my_nc_benchmark = self.load_benchmark(use_task_labels=True)
+        model, optimizer, criterion, benchmark = self.init_scenario(
+            multi_task=True
+        )
         strategy = JointTraining(
             model,
             optimizer,
@@ -300,20 +337,22 @@ class StrategyTest(unittest.TestCase):
             device=self.device,
             eval_mb_size=50,
             train_epochs=2,
-            plugins=[JointSTestPlugin(my_nc_benchmark)],
+            plugins=[JointSTestPlugin(benchmark)],
         )
         strategy.evaluator.loggers = [TextLogger(sys.stdout)]
-        strategy.train(my_nc_benchmark.train_stream)
+        strategy.train(benchmark.train_stream)
 
         # Raise error when retraining
         self.assertRaises(
             AlreadyTrainedError,
-            lambda: strategy.train(my_nc_benchmark.train_stream),
+            lambda: strategy.train(benchmark.train_stream),
         )
 
     def test_cwrstar(self):
         # SIT scenario
-        model, optimizer, criterion, my_nc_benchmark = self.init_sit()
+        model, optimizer, criterion, benchmark = self.init_scenario(
+            multi_task=False
+        )
         last_fc_name, _ = get_last_fc_layer(model)
         strategy = CWRStar(
             model,
@@ -323,16 +362,16 @@ class StrategyTest(unittest.TestCase):
             train_mb_size=64,
             device=self.device,
         )
-        self.run_strategy(my_nc_benchmark, strategy)
+        self.run_strategy(benchmark, strategy)
 
         dict_past_j = {}
-        for cls in range(my_nc_benchmark.n_classes):
+        for cls in range(benchmark.n_classes):
             dict_past_j[cls] = 0
 
         # Check past_j SIT
-        for exp in my_nc_benchmark.train_stream:
+        for exp in benchmark.train_stream:
             for cls in set(exp.dataset.targets):
-                dict_past_j[cls] += exp.dataset.targets.count(cls)
+                dict_past_j[cls] += exp.dataset.targets.count[cls]
         for cls in model.past_j.keys():
             assert model.past_j[cls] == dict_past_j[cls]
 
@@ -340,6 +379,9 @@ class StrategyTest(unittest.TestCase):
             model.past_j[cls] = 0
 
         # MT scenario
+        model, optimizer, criterion, benchmark = self.init_scenario(
+            multi_task=True
+        )
         strategy = CWRStar(
             model,
             optimizer,
@@ -348,7 +390,6 @@ class StrategyTest(unittest.TestCase):
             train_mb_size=64,
             device=self.device,
         )
-        benchmark = self.load_benchmark(use_task_labels=True)
         # self.run_strategy(benchmark, strategy)
 
         # Check past_j MT
@@ -357,14 +398,16 @@ class StrategyTest(unittest.TestCase):
             dict_past_j[cls] = 0
 
         for exp in benchmark.train_stream:
-            for cls in set(exp.dataset.targets):
-                dict_past_j[cls] += exp.dataset.targets.count(cls)
+            for cls, numcls in set(exp.dataset.targets.count.items()):
+                dict_past_j[cls] += numcls
         for cls in model.past_j.keys():
             assert model.past_j[cls] == dict_past_j[cls]
 
     def test_replay(self):
         # SIT scenario
-        model, optimizer, criterion, my_nc_benchmark = self.init_sit()
+        model, optimizer, criterion, benchmark = self.init_scenario(
+            multi_task=False
+        )
         strategy = Replay(
             model,
             optimizer,
@@ -375,9 +418,12 @@ class StrategyTest(unittest.TestCase):
             eval_mb_size=50,
             train_epochs=2,
         )
-        self.run_strategy(my_nc_benchmark, strategy)
+        self.run_strategy(benchmark, strategy)
 
         # MT scenario
+        model, optimizer, criterion, benchmark = self.init_scenario(
+            multi_task=True
+        )
         strategy = Replay(
             model,
             optimizer,
@@ -388,12 +434,13 @@ class StrategyTest(unittest.TestCase):
             eval_mb_size=50,
             train_epochs=2,
         )
-        benchmark = self.load_benchmark(use_task_labels=True)
         self.run_strategy(benchmark, strategy)
 
     def test_gdumb(self):
         # SIT scenario
-        model, optimizer, criterion, my_nc_benchmark = self.init_sit()
+        model, optimizer, criterion, benchmark = self.init_scenario(
+            multi_task=False
+        )
         strategy = GDumb(
             model,
             optimizer,
@@ -404,9 +451,12 @@ class StrategyTest(unittest.TestCase):
             eval_mb_size=50,
             train_epochs=2,
         )
-        self.run_strategy(my_nc_benchmark, strategy)
+        self.run_strategy(benchmark, strategy)
 
         # MT scenario
+        model, optimizer, criterion, benchmark = self.init_scenario(
+            multi_task=True
+        )
         strategy = GDumb(
             model,
             optimizer,
@@ -417,12 +467,13 @@ class StrategyTest(unittest.TestCase):
             eval_mb_size=50,
             train_epochs=2,
         )
-        benchmark = self.load_benchmark(use_task_labels=True)
         self.run_strategy(benchmark, strategy)
 
     def test_cumulative(self):
         # SIT scenario
-        model, optimizer, criterion, my_nc_benchmark = self.init_sit()
+        model, optimizer, criterion, benchmark = self.init_scenario(
+            multi_task=False
+        )
         strategy = Cumulative(
             model,
             optimizer,
@@ -432,9 +483,12 @@ class StrategyTest(unittest.TestCase):
             eval_mb_size=50,
             train_epochs=2,
         )
-        self.run_strategy(my_nc_benchmark, strategy)
+        self.run_strategy(benchmark, strategy)
 
         # MT scenario
+        model, optimizer, criterion, benchmark = self.init_scenario(
+            multi_task=True
+        )
         strategy = Cumulative(
             model,
             optimizer,
@@ -444,11 +498,10 @@ class StrategyTest(unittest.TestCase):
             eval_mb_size=50,
             train_epochs=2,
         )
-        benchmark = self.load_benchmark(use_task_labels=True)
         self.run_strategy(benchmark, strategy)
 
     def test_slda(self):
-        model, _, criterion, my_nc_benchmark = self.init_sit()
+        model, _, criterion, benchmark = self.init_scenario(multi_task=False)
         strategy = StreamingLDA(
             model,
             criterion,
@@ -460,10 +513,10 @@ class StrategyTest(unittest.TestCase):
             device=self.device,
             train_mb_size=7,
         )
-        self.run_strategy(my_nc_benchmark, strategy)
+        self.run_strategy(benchmark, strategy)
 
     def test_warning_slda_lwf(self):
-        model, _, criterion, my_nc_benchmark = self.init_sit()
+        model, _, criterion, benchmark = self.init_scenario(multi_task=False)
         with self.assertWarns(Warning) as cm:
             StreamingLDA(
                 model,
@@ -476,7 +529,9 @@ class StrategyTest(unittest.TestCase):
 
     def test_lwf(self):
         # SIT scenario
-        model, optimizer, criterion, my_nc_benchmark = self.init_sit()
+        model, optimizer, criterion, benchmark = self.init_scenario(
+            multi_task=False
+        )
         strategy = LwF(
             model,
             optimizer,
@@ -488,9 +543,12 @@ class StrategyTest(unittest.TestCase):
             eval_mb_size=50,
             train_epochs=2,
         )
-        self.run_strategy(my_nc_benchmark, strategy)
+        self.run_strategy(benchmark, strategy)
 
         # MT scenario
+        model, optimizer, criterion, benchmark = self.init_scenario(
+            multi_task=True
+        )
         strategy = LwF(
             model,
             optimizer,
@@ -502,12 +560,13 @@ class StrategyTest(unittest.TestCase):
             eval_mb_size=50,
             train_epochs=2,
         )
-        benchmark = self.load_benchmark(use_task_labels=True)
         self.run_strategy(benchmark, strategy)
 
     def test_agem(self):
         # SIT scenario
-        model, optimizer, criterion, my_nc_benchmark = self.init_sit()
+        model, optimizer, criterion, benchmark = self.init_scenario(
+            multi_task=False
+        )
         strategy = AGEM(
             model,
             optimizer,
@@ -518,9 +577,12 @@ class StrategyTest(unittest.TestCase):
             eval_mb_size=50,
             train_epochs=2,
         )
-        self.run_strategy(my_nc_benchmark, strategy)
+        self.run_strategy(benchmark, strategy)
 
         # MT scenario
+        model, optimizer, criterion, benchmark = self.init_scenario(
+            multi_task=True
+        )
         strategy = AGEM(
             model,
             optimizer,
@@ -531,12 +593,13 @@ class StrategyTest(unittest.TestCase):
             eval_mb_size=50,
             train_epochs=2,
         )
-        benchmark = self.load_benchmark(use_task_labels=True)
         self.run_strategy(benchmark, strategy)
 
     def test_gem(self):
         # SIT scenario
-        model, optimizer, criterion, my_nc_benchmark = self.init_sit()
+        model, optimizer, criterion, benchmark = self.init_scenario(
+            multi_task=False
+        )
         strategy = GEM(
             model,
             optimizer,
@@ -547,9 +610,12 @@ class StrategyTest(unittest.TestCase):
             train_epochs=2,
         )
 
-        self.run_strategy(my_nc_benchmark, strategy)
+        self.run_strategy(benchmark, strategy)
 
         # MT scenario
+        model, optimizer, criterion, benchmark = self.init_scenario(
+            multi_task=True
+        )
         strategy = GEM(
             model,
             optimizer,
@@ -559,13 +625,14 @@ class StrategyTest(unittest.TestCase):
             eval_mb_size=50,
             train_epochs=2,
         )
-        self.run_strategy(my_nc_benchmark, strategy)
         benchmark = self.load_benchmark(use_task_labels=True)
         self.run_strategy(benchmark, strategy)
 
     def test_ewc(self):
         # SIT scenario
-        model, optimizer, criterion, my_nc_benchmark = self.init_sit()
+        model, optimizer, criterion, benchmark = self.init_scenario(
+            multi_task=False
+        )
         strategy = EWC(
             model,
             optimizer,
@@ -577,9 +644,12 @@ class StrategyTest(unittest.TestCase):
             train_epochs=2,
         )
 
-        self.run_strategy(my_nc_benchmark, strategy)
+        self.run_strategy(benchmark, strategy)
 
         # MT scenario
+        model, optimizer, criterion, benchmark = self.init_scenario(
+            multi_task=True
+        )
         strategy = EWC(
             model,
             optimizer,
@@ -590,12 +660,13 @@ class StrategyTest(unittest.TestCase):
             eval_mb_size=50,
             train_epochs=2,
         )
-        benchmark = self.load_benchmark(use_task_labels=True)
         self.run_strategy(benchmark, strategy)
 
     def test_ewc_online(self):
         # SIT scenario
-        model, optimizer, criterion, my_nc_benchmark = self.init_sit()
+        model, optimizer, criterion, benchmark = self.init_scenario(
+            multi_task=False
+        )
         strategy = EWC(
             model,
             optimizer,
@@ -607,9 +678,11 @@ class StrategyTest(unittest.TestCase):
             eval_mb_size=50,
             train_epochs=2,
         )
-        self.run_strategy(my_nc_benchmark, strategy)
+        self.run_strategy(benchmark, strategy)
 
-        # MT scenario
+        # # MT scenario
+        model, optimizer, criterion, benchmark = self.init_scenario(
+            multi_task=True)
         strategy = EWC(
             model,
             optimizer,
@@ -621,12 +694,13 @@ class StrategyTest(unittest.TestCase):
             eval_mb_size=50,
             train_epochs=2,
         )
-        benchmark = self.load_benchmark(use_task_labels=True)
         self.run_strategy(benchmark, strategy)
 
     def test_rwalk(self):
         # SIT scenario
-        model, optimizer, criterion, my_nc_benchmark = self.init_sit()
+        model, optimizer, criterion, benchmark = self.init_scenario(
+            multi_task=False
+        )
         strategy = Naive(
             model,
             optimizer,
@@ -642,9 +716,11 @@ class StrategyTest(unittest.TestCase):
                 ),
             ],
         )
-        self.run_strategy(my_nc_benchmark, strategy)
+        self.run_strategy(benchmark, strategy)
 
-        # MT scenario
+        # # MT scenario
+        model, optimizer, criterion, benchmark = self.init_scenario(
+            multi_task=True)
         strategy = Naive(
             model,
             optimizer,
@@ -660,12 +736,13 @@ class StrategyTest(unittest.TestCase):
                 ),
             ],
         )
-        benchmark = self.load_benchmark(use_task_labels=True)
         self.run_strategy(benchmark, strategy)
 
     def test_synaptic_intelligence(self):
         # SIT scenario
-        model, optimizer, criterion, my_nc_benchmark = self.init_sit()
+        model, optimizer, criterion, benchmark = self.init_scenario(
+            multi_task=False
+        )
         strategy = SynapticIntelligence(
             model,
             optimizer,
@@ -675,10 +752,11 @@ class StrategyTest(unittest.TestCase):
             train_mb_size=10,
             eval_mb_size=10,
         )
-        benchmark = self.load_benchmark(use_task_labels=False)
         self.run_strategy(benchmark, strategy)
 
         # MT scenario
+        model, optimizer, criterion, benchmark = self.init_scenario(
+            multi_task=True)
         strategy = SynapticIntelligence(
             model,
             optimizer,
@@ -688,7 +766,6 @@ class StrategyTest(unittest.TestCase):
             train_mb_size=10,
             eval_mb_size=10,
         )
-        benchmark = self.load_benchmark(use_task_labels=True)
         self.run_strategy(benchmark, strategy)
 
     def test_cope(self):
@@ -697,7 +774,9 @@ class StrategyTest(unittest.TestCase):
         emb_size = n_classes  # Embedding size
 
         # SIT scenario
-        model, optimizer, criterion, my_nc_benchmark = self.init_sit()
+        model, optimizer, criterion, benchmark = self.init_scenario(
+            multi_task=False
+        )
         strategy = CoPE(
             model,
             optimizer,
@@ -710,23 +789,24 @@ class StrategyTest(unittest.TestCase):
             eval_mb_size=50,
             train_epochs=2,
         )
-        self.run_strategy(my_nc_benchmark, strategy)
+        self.run_strategy(benchmark, strategy)
 
         # MT scenario
-        strategy = CoPE(
-            model,
-            optimizer,
-            criterion,
-            mem_size=10,
-            n_classes=n_classes,
-            p_size=emb_size,
-            train_mb_size=10,
-            device=self.device,
-            eval_mb_size=50,
-            train_epochs=2,
-        )
-        benchmark = self.load_benchmark(use_task_labels=True)
-        self.run_strategy(benchmark, strategy)
+        # model, optimizer, criterion, benchmark = self.init_scenario(
+        #     multi_task=True)
+        # strategy = CoPE(
+        #     model,
+        #     optimizer,
+        #     criterion,
+        #     mem_size=10,
+        #     n_classes=n_classes,
+        #     p_size=emb_size,
+        #     train_mb_size=10,
+        #     device=self.device,
+        #     eval_mb_size=50,
+        #     train_epochs=2,
+        # )
+        # self.run_strategy(benchmark, strategy)
 
     def test_pnn(self):
         # only multi-task scenarios.
@@ -749,7 +829,9 @@ class StrategyTest(unittest.TestCase):
         strategy.eval(benchmark.test_stream)
 
     def test_icarl(self):
-        model, optimizer, criterion, benchmark = self.init_sit()
+        model, optimizer, criterion, benchmark = self.init_scenario(
+            multi_task=False
+        )
 
         strategy = ICaRL(
             model.features,
@@ -770,7 +852,9 @@ class StrategyTest(unittest.TestCase):
     def test_lfl(self):
 
         # SIT scenario
-        model, optimizer, criterion, my_nc_benchmark = self.init_sit()
+        model, optimizer, criterion, benchmark = self.init_scenario(
+            multi_task=False
+        )
         strategy = LFL(
             model,
             optimizer,
@@ -781,25 +865,28 @@ class StrategyTest(unittest.TestCase):
             eval_mb_size=50,
             train_epochs=2,
         )
-        self.run_strategy(my_nc_benchmark, strategy)
+        self.run_strategy(benchmark, strategy)
 
         # MT scenario
-        strategy = LFL(
-            model,
-            optimizer,
-            criterion,
-            lambda_e=0.0001,
-            train_mb_size=10,
-            device=self.device,
-            eval_mb_size=50,
-            train_epochs=2,
-        )
-        benchmark = self.load_benchmark(use_task_labels=True)
-        self.run_strategy(benchmark, strategy)
+        # model, optimizer, criterion, benchmark = self.init_scenario(
+        #     multi_task=True)
+        # strategy = LFL(
+        #     model,
+        #     optimizer,
+        #     criterion,
+        #     lambda_e=0.0001,
+        #     train_mb_size=10,
+        #     device=self.device,
+        #     eval_mb_size=50,
+        #     train_epochs=2,
+        # )
+        # self.run_strategy(benchmark, strategy)
 
     def test_mas(self):
         # SIT scenario
-        model, optimizer, criterion, my_nc_benchmark = self.init_sit()
+        model, optimizer, criterion, benchmark = self.init_scenario(
+            multi_task=False
+        )
         strategy = MAS(
             model,
             optimizer,
@@ -811,21 +898,98 @@ class StrategyTest(unittest.TestCase):
             eval_mb_size=50,
             train_epochs=2,
         )
-        self.run_strategy(my_nc_benchmark, strategy)
+        self.run_strategy(benchmark, strategy)
 
         # MT scenario
-        strategy = MAS(
+        # model, optimizer, criterion, benchmark = self.init_scenario(
+        #     multi_task=True)
+        # strategy = MAS(
+        #     model,
+        #     optimizer,
+        #     criterion,
+        #     lambda_reg=1.0,
+        #     alpha=0.5,
+        #     train_mb_size=10,
+        #     device=self.device,
+        #     eval_mb_size=50,
+        #     train_epochs=2,
+        # )
+        # self.run_strategy(benchmark, strategy)
+    
+    def test_bic(self):
+        # SIT scenario
+        model, optimizer, criterion, benchmark = self.init_scenario(
+            multi_task=False
+        )
+        strategy = BiC(
             model,
             optimizer,
             criterion,
-            lambda_reg=1.0,
-            alpha=0.5,
+            mem_size=50,
+            val_percentage=0.1,
+            T=2,
+            stage_2_epochs=10,
+            lamb=-1,
+            lr=0.01,
+            train_mb_size=10,
+            device=self.device,
+            eval_mb_size=50,
+            train_epochs=2,
+        )
+        self.run_strategy(benchmark, strategy)
+
+    def test_mir(self):
+        # SIT scenario
+        model, optimizer, criterion, benchmark = self.init_scenario(
+            multi_task=False
+        )
+        strategy = MIR(
+            model,
+            optimizer,
+            criterion,
+            mem_size=1000,
+            batch_size_mem=10,
+            subsample=50,
+            train_mb_size=10,
+            device=self.device,
+            eval_mb_size=50,
+            train_epochs=2,
+        )
+        self.run_strategy(benchmark, strategy)
+
+        # MT scenario
+        model, optimizer, criterion, benchmark = self.init_scenario(
+            multi_task=True)
+        strategy = MIR(
+            model,
+            optimizer,
+            criterion,
+            mem_size=1000,
+            batch_size_mem=10,
+            subsample=50,
+            train_mb_size=10,
+            device=self.device,
+            eval_mb_size=50,
+            train_epochs=2,
+        )
+        self.run_strategy(benchmark, strategy)
+
+    def test_erace(self):
+        # SIT scenario
+        model, optimizer, criterion, benchmark = self.init_scenario(
+            multi_task=False
+        )
+        strategy = ER_ACE(
+            model,
+            optimizer,
+            criterion,
+            mem_size=1000,
+            batch_size_mem=10,
             train_mb_size=10,
             device=self.device,
             eval_mb_size=50,
             train_epochs=2,
         )
-        benchmark = self.load_benchmark(use_task_labels=True)
         self.run_strategy(benchmark, strategy)
 
     def load_benchmark(self, use_task_labels=False):
@@ -837,14 +1001,20 @@ class StrategyTest(unittest.TestCase):
         """
         return get_fast_benchmark(use_task_labels=use_task_labels)
 
-    def get_model(self, fast_test=False):
+    def get_model(self, fast_test=False, multi_task=False):
         if fast_test:
-            model = SimpleMLP(input_size=6, hidden_size=10)
+            if multi_task:
+                model = MTSimpleMLP(input_size=6, hidden_size=10)
+            else:
+                model = SimpleMLP(input_size=6, hidden_size=10)
             # model.classifier = IncrementalClassifier(
             #     model.classifier.in_features)
             return model
         else:
-            model = SimpleMLP()
+            if multi_task:
+                model = MTSimpleMLP()
+            else:
+                model = SimpleMLP()
             # model.classifier = IncrementalClassifier(
             #     model.classifier.in_features)
             return model
