@@ -26,8 +26,11 @@ from avalanche.training.supervised.cumulative import Cumulative
 from avalanche.evaluation.metrics import StreamAccuracy, ExperienceAccuracy
 from avalanche.training.supervised.strategy_wrappers import PNNStrategy
 
-from tests.unit_tests_utils import get_fast_benchmark, get_device, \
-    set_deterministic_run
+from tests.unit_tests_utils import (
+    get_fast_benchmark,
+    get_device,
+    set_deterministic_run,
+)
 
 
 class TestMLP(nn.Module):
@@ -94,11 +97,7 @@ class StrategyTest(unittest.TestCase):
             strategy.train(train_batch_info)
         strategy.eval(benchmark.train_stream[:])
         print("TRAIN STREAM ACC: ", main_metric.result())
-        assert (
-            sum(main_metric.result().values())
-            / float(len(main_metric.result().keys()))
-            > 0.7
-        )
+        assert main_metric.result() > 0.7
 
     def test_pnn(self):
         # check that pnn reaches high enough accuracy.
@@ -127,11 +126,7 @@ class StrategyTest(unittest.TestCase):
 
         strategy.eval(benchmark.train_stream[:])
         print("TRAIN STREAM ACC: ", main_metric.result())
-        assert (
-            sum(main_metric.result().values())
-            / float(len(main_metric.result().keys()))
-            > 0.5
-        )
+        assert main_metric.result() > 0.5
 
 
 if __name__ == "__main__":
